==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/LinksQrcode.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksQrcodeQrcode;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksQrcode
 */
@JsonPropertyOrder({ LinksQrcode.JSON_PROPERTY_QRCODE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksQrcode implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_QRCODE = "qrcode";
    private LinksQrcodeQrcode qrcode;

    public LinksQrcode() {
    }

    public LinksQrcode qrcode(LinksQrcodeQrcode qrcode) {

        this.qrcode = qrcode;
        return this;
    }

    /**
     * Get qrcode
     *
     * @return qrcode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_QRCODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksQrcodeQrcode getQrcode() {
        return qrcode;
    }

    @JsonProperty(JSON_PROPERTY_QRCODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setQrcode(LinksQrcodeQrcode qrcode) {
        this.qrcode = qrcode;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksQrcode linksQrcode = (LinksQrcode) o;
        return Objects.equals(this.qrcode, linksQrcode.qrcode);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(qrcode);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksQrcode {\n");
        sb.append("    qrcode: ").append(toIndentedString(qrcode)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/LinksQrcode.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksQrcodeQrcode;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksQrcode
 */
@JsonPropertyOrder({ LinksQrcode.JSON_PROPERTY_QRCODE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksQrcode implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_QRCODE = "qrcode";
    private LinksQrcodeQrcode qrcode;

    public LinksQrcode() {
    }

    public LinksQrcode qrcode(LinksQrcodeQrcode qrcode) {

        this.qrcode = qrcode;
        return this;
    }

    /**
     * Get qrcode
     *
     * @return qrcode
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_QRCODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksQrcodeQrcode getQrcode() {
        return qrcode;
    }

    @JsonProperty(JSON_PROPERTY_QRCODE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setQrcode(LinksQrcodeQrcode qrcode) {
        this.qrcode = qrcode;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksQrcode linksQrcode = (LinksQrcode) o;
        return Objects.equals(this.qrcode, linksQrcode.qrcode);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(qrcode);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksQrcode {\n");
        sb.append("    qrcode: ").append(toIndentedString(qrcode)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
